/****************************************************************************
** Meta object code from reading C++ file 'kmousetool.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kmousetool-17.12.3/kmousetool/kmousetool.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmousetool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMouseTool_t {
    QByteArrayData data[12];
    char stringdata0[162];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMouseTool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMouseTool_t qt_meta_stringdata_KMouseTool = {
    {
QT_MOC_LITERAL(0, 0, 10), // "KMouseTool"
QT_MOC_LITERAL(1, 11, 15), // "settingsChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 17), // "startStopSelected"
QT_MOC_LITERAL(4, 46, 15), // "defaultSelected"
QT_MOC_LITERAL(5, 62, 13), // "resetSelected"
QT_MOC_LITERAL(6, 76, 13), // "applySelected"
QT_MOC_LITERAL(7, 90, 12), // "helpSelected"
QT_MOC_LITERAL(8, 103, 13), // "closeSelected"
QT_MOC_LITERAL(9, 117, 12), // "quitSelected"
QT_MOC_LITERAL(10, 130, 13), // "aboutSelected"
QT_MOC_LITERAL(11, 144, 17) // "configureSelected"

    },
    "KMouseTool\0settingsChanged\0\0"
    "startStopSelected\0defaultSelected\0"
    "resetSelected\0applySelected\0helpSelected\0"
    "closeSelected\0quitSelected\0aboutSelected\0"
    "configureSelected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMouseTool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x0a /* Public */,
       3,    0,   65,    2, 0x0a /* Public */,
       4,    0,   66,    2, 0x0a /* Public */,
       5,    0,   67,    2, 0x0a /* Public */,
       6,    0,   68,    2, 0x0a /* Public */,
       7,    0,   69,    2, 0x0a /* Public */,
       8,    0,   70,    2, 0x0a /* Public */,
       9,    0,   71,    2, 0x0a /* Public */,
      10,    0,   72,    2, 0x0a /* Public */,
      11,    0,   73,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KMouseTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMouseTool *_t = static_cast<KMouseTool *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->startStopSelected(); break;
        case 2: _t->defaultSelected(); break;
        case 3: _t->resetSelected(); break;
        case 4: _t->applySelected(); break;
        case 5: _t->helpSelected(); break;
        case 6: _t->closeSelected(); break;
        case 7: _t->quitSelected(); break;
        case 8: _t->aboutSelected(); break;
        case 9: _t->configureSelected(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KMouseTool::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KMouseTool.data,
      qt_meta_data_KMouseTool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMouseTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMouseTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMouseTool.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::KMouseToolUI"))
        return static_cast< Ui::KMouseToolUI*>(this);
    return QWidget::qt_metacast(_clname);
}

int KMouseTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
struct qt_meta_stringdata_KMouseToolTray_t {
    QByteArrayData data[6];
    char stringdata0[79];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMouseToolTray_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMouseToolTray_t qt_meta_stringdata_KMouseToolTray = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KMouseToolTray"
QT_MOC_LITERAL(1, 15, 17), // "startStopSelected"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 17), // "configureSelected"
QT_MOC_LITERAL(4, 52, 13), // "aboutSelected"
QT_MOC_LITERAL(5, 66, 12) // "helpSelected"

    },
    "KMouseToolTray\0startStopSelected\0\0"
    "configureSelected\0aboutSelected\0"
    "helpSelected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMouseToolTray[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,
       3,    0,   35,    2, 0x06 /* Public */,
       4,    0,   36,    2, 0x06 /* Public */,
       5,    0,   37,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KMouseToolTray::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMouseToolTray *_t = static_cast<KMouseToolTray *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->startStopSelected(); break;
        case 1: _t->configureSelected(); break;
        case 2: _t->aboutSelected(); break;
        case 3: _t->helpSelected(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KMouseToolTray::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KMouseToolTray::startStopSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KMouseToolTray::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KMouseToolTray::configureSelected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KMouseToolTray::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KMouseToolTray::aboutSelected)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KMouseToolTray::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KMouseToolTray::helpSelected)) {
                *result = 3;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KMouseToolTray::staticMetaObject = {
    { &KStatusNotifierItem::staticMetaObject, qt_meta_stringdata_KMouseToolTray.data,
      qt_meta_data_KMouseToolTray,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMouseToolTray::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMouseToolTray::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMouseToolTray.stringdata0))
        return static_cast<void*>(this);
    return KStatusNotifierItem::qt_metacast(_clname);
}

int KMouseToolTray::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KStatusNotifierItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KMouseToolTray::startStopSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KMouseToolTray::configureSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KMouseToolTray::aboutSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KMouseToolTray::helpSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
